goog.workspace.meet

Clojure wrapper for the Google Meet API (v2).

Provides idiomatic Clojure functions for reading and managing meeting spaces, conference records, participants, recordings, and transcripts.

Auth: use csl/scoped-delegated-credentials with the appropriate scope:

  • MeetScopes/MEETINGS_SPACE_READONLY (read-only access)
  • MeetScopes/MEETINGS_SPACE_CREATED (read + manage created spaces)
  • MeetScopes/MEETINGS_SPACE_SETTINGS (update space settings)

All list functions return {:data [...] :next-page-token "..."}; the caller is responsible for pagination by passing :page-token from one call to the next. :next-page-token is absent when there are no further pages.

All functions return {:data ...} on success or {:error ...} on failure.

Clojure wrapper for the Google Meet API (v2).

Provides idiomatic Clojure functions for reading and managing meeting spaces,
conference records, participants, recordings, and transcripts.

Auth: use csl/scoped-delegated-credentials with the appropriate scope:
- MeetScopes/MEETINGS_SPACE_READONLY  (read-only access)
- MeetScopes/MEETINGS_SPACE_CREATED   (read + manage created spaces)
- MeetScopes/MEETINGS_SPACE_SETTINGS  (update space settings)

All list functions return {:data [...] :next-page-token "..."}; the caller
is responsible for pagination by passing :page-token from one call to the next.
:next-page-token is absent when there are no further pages.

All functions return {:data ...} on success or {:error ...} on failure.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries